@@ -1,5 +1,5 @@
 package Yahoo::Marketing::ForecastKeyword;
-# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -14,10 +14,8 @@ Yahoo::Marketing::ForecastKeyword - an object to represent a Yahoo Marketing For
 
 sub _user_setable_attributes {
     return ( qw/ 
-                 contentMatchMaxBid
+                 customBid
                  keyword
-                 sponsoredSearchMaxBid
-                 matchType
             /  );
 }
 
@@ -34,24 +32,23 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V5/reference/dataObjects.php> for documentation of the various data objects.
 
 
-=head2 new
-
-Creates a new instance
-
 =cut
 
 =head1 METHODS
 
+=head2 new
+
+Creates a new instance
+
 =head2 get/set methods
 
 =over 8
 
-    contentMatchMaxBid
+    customBid
     keyword
-    sponsoredSearchMaxBid
 
 =back
 
